@@ -1,23 +1,14 @@
 import pandas as pd
 
 
-def datatype_check_bool(excel_file, sheet_name, column_name):
+def datatype_check_bool(column_df):
     # loading the file and basic file based error handling to be done
-    try:
-        df = pd.read_excel(excel_file, sheet_name=sheet_name,
-                           usecols=[column_name])
-    except FileNotFoundError:
-        return f"Error: {excel_file} does not exist."
-    except Exception as e:
-        return f"Error: Encountered while reading the file {e}"
-
-    if column_name not in df:
-        return f"Error: {column_name} not found in the sheet. Check and re-submit."
-    # convert it into a series
-    df_series = df[column_name]
+    
 
     def is_bool(value):
         # check first if the values are "True" or "False"
+        
+        
         if isinstance(value, bool):
             return True
         # if not then check if it is a string. It could be "true"/"false"
@@ -27,7 +18,8 @@ def datatype_check_bool(excel_file, sheet_name, column_name):
         # everything else is a fail case
         return False
 
-    non_missing_df = df_series.dropna()#drop empty values 
+    non_missing_df = column_df.dropna()#drop empty values 
+    # column_df = column_df == 1.0
 
     non_bool_mask = ~non_missing_df.apply(is_bool)
 
@@ -43,7 +35,6 @@ def datatype_check_bool(excel_file, sheet_name, column_name):
 
 
 if __name__ == "__main__":
-    result = datatype_check_bool(
-        "COH_Deliveries_TEMPLATE_22_23_Example_Data (1) (1).xlsx",
-        "Unique_Farmers", "All declared are mapped")
-    print(result)
+    df = pd.read_excel("Seedling_Distribution_TEMPLATE (1) vera data.xlsx", sheet_name="Seedling Database")
+    column_df = df["BC Farmer"]
+    print(datatype_check_bool(column_df))
\ No newline at end of file
