@@ -1,19 +1,11 @@
 import pandas as pd
 
 
-def datatype_check_integer(excel_file, sheet_name, column_name):
+def datatype_check_integer(column_df):
    
-    try:
-        df = pd.read_excel(excel_file, sheet_name=sheet_name, usecols=[column_name])
-    except FileNotFoundError:
-        return f"Error: {excel_file} does not exist."
-    except Exception as e:
-        return f"Error: Encountered while reading the file {e}"
+    
 
-    if column_name not in df:
-        return f"Error: {column_name} not found in the sheet. Check and re-submit."
-
-    df_series = df[column_name]
+    
 
     def is_integer(value):
         try:
@@ -21,7 +13,7 @@ def datatype_check_integer(excel_file, sheet_name, column_name):
         except ValueError:
             return False
 
-    non_missing_df = df_series.dropna()
+    non_missing_df = column_df.dropna()
 
     non_integer_mask = ~non_missing_df.apply(is_integer)
     # get a list as o/p with the datatype check result(True or false); invert it;
@@ -39,10 +31,10 @@ def datatype_check_integer(excel_file, sheet_name, column_name):
     }
 
 
-if __name__ == "__main__":
-    result = datatype_check_integer(
-        "COH_Deliveries_TEMPLATE_22_23_Example_Data (1) (1).xlsx",
-        "Unique_Farmers",
-        "COH delivered volume in KG",
-    )
-    print(result)
+# if __name__ == "__main__":
+#     result = datatype_check_integer(
+#         "COH_Deliveries_TEMPLATE_22_23_Example_Data (1) (1).xlsx",
+#         "Unique_Farmers",
+#         "COH delivered volume in KG",
+#     )
+#     print(result)
